

local buttongroup		= {}
buttongroup.__index		= buttongroup

local mouseclicked


function buttongroup.new( x, y )
	local self			= setmetatable( {}, buttongroup )
	self.x				= x
	self.y				= y
	self.buttons		= {}
	self.button_dis		= 32
	self.button_font	= FONT_NORMAL
	self.button_color	= { 255, 255, 255 }
	self.currentSel		= 1
	return self
end


function buttongroup:addButton( b )
	b.x					= self.x
	b.y					= self.y + self.button_dis * #self.buttons
	b.text				= b.text or "empty"
	b.font				= self.button_font
	b.width				= b.font:getWidth( b.text )
	b.height			= b.font:getHeight()
	b.color				= self.button_color
	table.insert( self.buttons, b )
end


function buttongroup:setDistance( dis )
	self.button_dis		= dis
end


function buttongroup:setFont( font )
	self.button_font	= font
end


function buttongroup:setColor( color )
	self.button_color	= color
end


function buttongroup:update(dt)
	mouseclicked		= false
end


function buttongroup:draw()
	for k,v in ipairs(self.buttons) do
	
		local mouse	= { x = love.mouse.getX(), y = love.mouse.getY(), width = 1, height = 1 }
		
		love.graphics.setFont( v.font )
		
	-- Is hovering?
		if ut.boxCollision( { x = v.x - v.width / 2, y = v.y, width = v.width, height = v.height } , mouse ) then
		
			self.currentSel = k
			
		-- is clicked ?
			if love.mouse.isDown('l') and not mouseclicked then
				v.funct()
				mouseclicked = true
			end
			
		end
		
	-- Display text
		if self.currentSel == k then
			love.graphics.setColor( v.color[1], v.color[2], v.color[3], 255 )
			love.graphics.printf( v.text, v.x - 200, v.y, 400, "center" )
			
		else
		
			love.graphics.setColor( v.color[1], v.color[2], v.color[3], 100  )
			love.graphics.printf( v.text, v.x - 200, v.y, 400, "center" )			
		
		end
	end
end


function buttongroup:keypressed(k)
	if k == ("up" or "w") and self.currentSel > 1 then self.currentSel = self.currentSel - 1
	elseif k == ("down" or "s") and self.currentSel < #self.buttons then self.currentSel = self.currentSel + 1
	elseif k == "return" then self.buttons[self.currentSel].funct()
	end
end


function buttongroup:mousereleased(x, y, b)
	if b == 'l' then mouseclicked  = false end
end


return buttongroup