

-- COMMANDS

local commands						= {}


local function newCommand( command, funct )
	local c = {}
	c.command = command
	c.funct = funct
	table.insert( commands, c )
end


-- A list of all commands to enter in the console, simply add one if needed
newCommand( "/version", function() console:newMessage("Game Version "..VERSION, { 255, 200, 200 } ) end )
newCommand( "/screenwidth", function() console:newMessage("Width: "..WIDTH, { 255, 200, 200 } ) end )
newCommand( "/screenheight", function() console:newMessage("Height: "..HEIGHT, { 255, 200, 200 } ) end )
newCommand( "/help", function()
			local list = ""
			for i = 1, #commands do
				list = list .. " " ..commands[i].command
			end
			console:newMessage("Commands:"..list, { 255, 200, 200 } )
			end )
		
		
-- CONSOLE

local console						= {}


function console:init()
	self.boxColor					= { 28, 70, 28 }
	self.alpha						= 50
	self.visible					= true
	self.width						= WIDTH
	self.height						= 96
	self.x							= 0
	self.y							= HEIGHT - self.height
	self.text_table					= {}
	self.text_dis					= 16
	self.text_cur					= 0
	console:newMessage( "Welcome to Desert Island!", { 255, 255, 255 } )
	console:newMessage( "For a list with available commands type '/help' ")
	console:newMessage()
end


function console:switch()
	self.visible = not self.visible
end


function console:isVisible()
	return self.visible
end


function console:newMessage( text, color )

	local txt						= {}
	txt.x							= self.x + 8
	txt.y							= self.y + self.height - self.text_dis
	txt.text						= text or ""
	txt.color						= color or { 255, 255, 255 }
	
	if #self.text_table > 0 then
		if self.text_table[1].y < self.y + self.text_dis * 2 then
			table.remove( self.text_table, 1  )
		end
	end
	
	for i,v in ipairs( self.text_table ) do
		v.y = v.y - self.text_dis
	end
	
	table.insert( self.text_table, txt )
	self.text_cur = #self.text_table
	
end


function console:update(dt)	
end


function console:draw()

	if self.visible then
	
		love.graphics.setColor( self.boxColor[1], self.boxColor[2], self.boxColor[3], self.alpha )
		love.graphics.rectangle( "fill", self.x, self.y, self.width, self.height )
		
		for k,v in ipairs( self.text_table ) do
			love.graphics.setFont( FONT_SMALL )
			if self.text_cur == k then
				love.graphics.setColor( v.color[1], v.color[2], v.color[3], 255 )
				love.graphics.print( v.text.."_", v.x, v.y )
			else
				love.graphics.setColor( v.color[1], v.color[2], v.color[3], 175 )
				love.graphics.print( v.text, v.x, v.y )
			end
		end
		
	end
	
end


function console:keypressed(k)
	local current = self.text_table[self.text_cur]
	if self.visible then

		if k == "delete" or k == "backspace" then
			current.text = current.text:sub( 1, math.max( 0, #current.text - 1 ) )
		elseif k and k:match( '^[%p%w%s]$' ) then current.text = current.text..k
		elseif k == "return" and current.text ~= "" then 
			for i = 1, #commands do
				if current.text == commands[i].command then
					commands[i].funct()
				end
			end
			self:newMessage()
		end

	end
	
end


return console